@@ -1,3 +1,4 @@
+import inspect
 import re
 import textwrap
 from ast import parse as ast_parse
@@ -8,12 +9,7 @@ import black
 import toml
 
 from snakefmt import DEFAULT_LINE_LENGTH
-from snakefmt.exceptions import (
-    InvalidBlackConfiguration,
-    InvalidParameterSyntax,
-    InvalidPython,
-    MalformattedToml,
-)
+from snakefmt.exceptions import InvalidParameterSyntax, InvalidPython, MalformattedToml
 from snakefmt.parser.grammar import SnakeRule
 from snakefmt.parser.parser import Parser
 from snakefmt.parser.syntax import (
@@ -45,23 +41,24 @@ class Formatter(Parser):
     def __init__(
         self,
         snakefile: TokenIterator,
-        line_length: int = DEFAULT_LINE_LENGTH,
-        black_config: Optional[PathLike] = None,
+        line_length: Optional[int] = None,
+        black_config_file: Optional[PathLike] = None,
     ):
-        self._line_length: int = line_length
         self.result: str = ""
         self.lagging_comments: str = ""
         self.no_formatting_yet: bool = True
         self.last_recognised_keyword = ""
 
-        if black_config is None:
-            self.black_mode = black.FileMode(line_length=self.line_length)
-        else:
-            self.black_mode = self.read_black_config(black_config)
+        self.black_mode = black.FileMode(line_length=DEFAULT_LINE_LENGTH)
+        if black_config_file is not None:
+            self.read_black_config(black_config_file)
+
+        if line_length is not None:
+            self.black_mode.line_length = line_length
 
         super().__init__(snakefile)  # Call to parse snakefile
 
-    def read_black_config(self, path: PathLike) -> black.FileMode:
+    def read_black_config(self, path: PathLike) -> None:
         if not Path(path).is_file():
             raise FileNotFoundError(f"{path} is not a file.")
 
@@ -71,17 +68,20 @@ class Formatter(Parser):
         except toml.TomlDecodeError as error:
             raise MalformattedToml(error)
 
-        if "line_length" not in config:
-            config["line_length"] = self.line_length
+        valid_black_filemode_params = inspect.getfullargspec(black.FileMode).args
 
-        try:
-            return black.FileMode(**config)
-        except TypeError as error:
-            raise InvalidBlackConfiguration(error)
+        for key, val in config.items():
+            # this is due to FileMode param being string_normalise, but CLI being
+            # skip_string_normalise - https://github.com/snakemake/snakefmt/issues/73
+            if key.startswith("skip"):
+                key = key[5:]
+                val = not val
 
-    @property
-    def line_length(self) -> int:
-        return self._line_length
+            key = key.replace("-", "_")
+            if key not in valid_black_filemode_params:
+                continue
+
+            setattr(self.black_mode, key, val)
 
     def get_formatted(self) -> str:
         return self.result
@@ -166,13 +166,8 @@ class Formatter(Parser):
     def run_black_format_str(self, string: str, target_indent: int) -> str:
         # need to let black know about indentation as it effects line length
         indent_line_length = target_indent * 4
-        line_length = (
-            self.black_mode.line_length
-            if self.context.from_python
-            else self.line_length
-        )
-        contextual_line_length = max(0, line_length - indent_line_length)
-        old_black_line_length = self.black_mode.line_length
+        saved_black_line_length = self.black_mode.line_length
+        contextual_line_length = max(0, saved_black_line_length - indent_line_length)
         self.black_mode.line_length = contextual_line_length
         try:
             fmted = black.format_str(string, mode=self.black_mode)
@@ -180,7 +175,7 @@ class Formatter(Parser):
             raise InvalidPython(
                 f"Got error:\n```\n{str(e)}\n```\n" f"while formatting code with black."
             ) from None
-        self.black_mode.line_length = old_black_line_length
+        self.black_mode.line_length = saved_black_line_length
         return fmted
 
     def align_strings(self, string: str, target_indent: int) -> str:
